@@ -28,7 +28,7 @@ impl Tab {
                 .map(|(index, track)| Track::new_arc(weak_self.clone(), index, track))
                 .collect();
             let mut sections = Vec::new();
-            let mut add_section = |index: usize, section : notation_proto::prelude::Section| {
+            let mut add_section = |index: usize, section: notation_proto::prelude::Section| {
                 let section_id = section.id.clone();
                 match Section::try_new(weak_self.clone(), index, section, &tracks).map(Arc::new) {
                     Ok(section) => sections.push(section),
@@ -75,7 +75,12 @@ impl Tab {
             ));
             section_ordinal += 1;
             bar_ordinal += section.bars.len();
-            println!("new_tab_bars() section: {} <{}> -> {:?} bars", section.id, section.kind, section.bars.len());
+            println!(
+                "new_tab_bars() section: {} <{}> -> {:?} bars",
+                section.id,
+                section.kind,
+                section.bars.len()
+            );
         }
         println!("new_tab_bars() -> {:?} bars", bars.len());
         bars
